@@ -5,7 +5,7 @@
 :copyright: (c) 2021 Peopl3s
 """
 
-from .clubhouse import (ClubHouse, ClubHouseApiMethod, Machine)
+from .clubhouse import (Machine,)
 
 
 __author__ = 'Peopl3s'
